==> vue-code-generator-plugin-test-0.0.2.tgz: package/es/generator/plugins/project/vue3/plugins/router.js <==
import _extends from "@babel/runtime/helpers/extends";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { COMMON_CHUNK_NAME, ChunkType, FileType } from '@alilc/lowcode-code-generator';
var pluginFactory = function pluginFactory() {
  var plugin = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(pre) {
      var _ir$routes;
      var next, ir, routes, firtRoute;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            next = _extends({}, pre);
            ir = next.ir;
            routes = ir.routes;
            routes.map(function (route) {
              next.chunks.push({
                type: ChunkType.STRING,
                fileType: FileType.JS,
                name: COMMON_CHUNK_NAME.InternalDepsImport,
                content: "\n        import " + route.componentName + " from '@/pages/" + route.fileName + "/index.vue'\n        ",
                linkAfter: [COMMON_CHUNK_NAME.ExternalDepsImport]
              });
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: FileType.JS,
              name: COMMON_CHUNK_NAME.InternalDepsImport,
              content: "\n      import { createRouter, createWebHistory } from 'vue-router'\n      ",
              linkAfter: [COMMON_CHUNK_NAME.ExternalDepsImport]
            });
            firtRoute = (_ir$routes = ir.routes) === null || _ir$routes === void 0 ? void 0 : _ir$routes[0];
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: FileType.JS,
              name: COMMON_CHUNK_NAME.FileVarDefine,
              content: "\n      const router = createRouter({\n        history: createWebHistory(import.meta.env.BASE_URL),\n        routes: [\n          {\n            path: '/',\n            redirect: '" + firtRoute.path + "',\n          },\n          " + ir.routes.map(function (route) {
                return "\n                            {\n                              path: '" + route.path + "',\n                              component: " + route.componentName + ",\n                            }\n                          ";
              }).join(',') + "\n        ]\n      })\n      ",
              linkAfter: [COMMON_CHUNK_NAME.ExternalDepsImport, COMMON_CHUNK_NAME.InternalDepsImport, COMMON_CHUNK_NAME.ImportAliasDefine, COMMON_CHUNK_NAME.FileUtilDefine]
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: FileType.JS,
              name: COMMON_CHUNK_NAME.FileExport,
              content: "\n      export default router;\n      ",
              linkAfter: [COMMON_CHUNK_NAME.ExternalDepsImport, COMMON_CHUNK_NAME.InternalDepsImport, COMMON_CHUNK_NAME.FileUtilDefine, COMMON_CHUNK_NAME.ImportAliasDefine, COMMON_CHUNK_NAME.FileVarDefine, COMMON_CHUNK_NAME.FileMainContent]
            });
            return _context.abrupt("return", next);
          case 9:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return function plugin(_x) {
      return _ref.apply(this, arguments);
    };
  }();
  return plugin;
};
export default pluginFactory;

==> vue-code-generator-plugin-test-0.0.3.tgz: package/es/generator/plugins/project/vue3/plugins/router.js <==
import _extends from "@babel/runtime/helpers/extends";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { COMMON_CHUNK_NAME, ChunkType, FileType } from '@alilc/lowcode-code-generator';
var pluginFactory = function pluginFactory() {
  var plugin = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(pre) {
      var _ir$routes;
      var next, ir, routes, firtRoute;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            next = _extends({}, pre);
            ir = next.ir;
            routes = ir.routes;
            routes.forEach(function (route) {
              next.chunks.push({
                type: ChunkType.STRING,
                fileType: FileType.JS,
                name: COMMON_CHUNK_NAME.InternalDepsImport,
                content: "\n        import " + route.componentName + " from '@/pages/" + route.componentName + "/index.vue'\n        ",
                linkAfter: [COMMON_CHUNK_NAME.ExternalDepsImport]
              });
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: FileType.JS,
              name: COMMON_CHUNK_NAME.InternalDepsImport,
              content: "\n      import { createRouter, createWebHistory } from 'vue-router'\n      ",
              linkAfter: [COMMON_CHUNK_NAME.ExternalDepsImport]
            });
            firtRoute = (_ir$routes = ir.routes) === null || _ir$routes === void 0 ? void 0 : _ir$routes[0];
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: FileType.JS,
              name: COMMON_CHUNK_NAME.FileVarDefine,
              content: "\n      const router = createRouter({\n        history: createWebHistory(import.meta.env.BASE_URL),\n        routes: [\n          {\n            path: '/',\n            redirect: '/" + firtRoute.componentName + "',\n          },\n          " + ir.routes.map(function (route) {
                return "\n                            {\n                              path: '/" + route.componentName + "',\n                              component: " + route.componentName + ",\n                            }\n                          ";
              }).join(',') + "\n        ]\n      })\n      ",
              linkAfter: [COMMON_CHUNK_NAME.ExternalDepsImport, COMMON_CHUNK_NAME.InternalDepsImport, COMMON_CHUNK_NAME.ImportAliasDefine, COMMON_CHUNK_NAME.FileUtilDefine]
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: FileType.JS,
              name: COMMON_CHUNK_NAME.FileExport,
              content: "\n      export default router;\n      ",
              linkAfter: [COMMON_CHUNK_NAME.ExternalDepsImport, COMMON_CHUNK_NAME.InternalDepsImport, COMMON_CHUNK_NAME.FileUtilDefine, COMMON_CHUNK_NAME.ImportAliasDefine, COMMON_CHUNK_NAME.FileVarDefine, COMMON_CHUNK_NAME.FileMainContent]
            });
            return _context.abrupt("return", next);
          case 9:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return function plugin(_x) {
      return _ref.apply(this, arguments);
    };
  }();
  return plugin;
};
export default pluginFactory;
